@@ -765,10 +765,12 @@ class Colony:
         result = json.loads(resp.text)
         return [Converters.create_user_invitation_response(x) for x in result]
 
-    def test_invite_exists(self, secret: str):
+    def get_invited_user_details_by_secret(self, secret: str):
         method_url = self._api_root.account.account_signup_by_secret(secret=secret)
         resp = self.session.get(url=method_url)
-        return resp.status_code
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        result = json.loads(resp.text)
+        return Converters.create_invited_user_details_response(result)
 
     def remove_invites(self, emails: List[str]):
         method_url = self._api_root.account.account_invitations()
@@ -1054,9 +1056,11 @@ class Colony:
         response = self.session.put(url=url, json=request_json)
         GatewayUtils.handle_response(response=response, return_codes=return_codes)
 
-    def set_account_extra_details(self, account_name: str, sso_enabled: bool, anonymous_users: bool):
+    def set_account_extra_details(self, account_name: str, sso_enabled: bool, anonymous_users: bool,
+                                  sso_update_enabled: bool):
         set_account_extra_details_url = self._api_root.account.set_account_extra_details(account_name)
-        self.put_request(set_account_extra_details_url, {"sso_enabled": sso_enabled, "anonymous_users": anonymous_users}
+        self.put_request(set_account_extra_details_url, {"sso_enabled": sso_enabled, "anonymous_users": anonymous_users,
+                                                         "sso_update_enabled": sso_update_enabled}
                          , return_codes=[200])
 
     def get_account_extra_details(self, account_name: str):
@@ -1212,6 +1216,13 @@ class Colony:
         response_json = json.loads(response.text)
         return Converters.aws_cloud_provider_settings_model(data=response_json)
 
+    def get_insided_token(self):
+        method_url = self._api_root.integration.get_insided_token()
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.insided_token_model(data=response_json)
+
 
 class SandboxesHandler:
     def __init__(self):
