@@ -3,7 +3,7 @@ from datetime import datetime
 import dateutil.parser
 from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
-from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
+from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel, InsidedTokenResponseModel
 from gateways.common.cs18_api_responses import (
     SpaceAdmin,
     SpaceCloudAccount,
@@ -51,7 +51,7 @@ from gateways.common.cs18_api_responses import (
     AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
     SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse, ParameterStoreItem,
     ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue, CloudRegionResponse,
-    CloudComputeServiceResponse)
+    CloudComputeServiceResponse, InvitedUserDetailsResponse)
 
 
 class Converters:
@@ -801,6 +801,18 @@ class Converters:
             space_role=invite["space_role"],
         )
 
+    @staticmethod
+    def create_invited_user_details_response(invited_user_details: dict) -> InvitedUserDetailsResponse:
+        """
+        Returns InvitedUserDetailsResponse based on provided dictionary
+        :param invited_user_details: dict
+        :return: InvitedUserDetailsResponse
+        """
+        return InvitedUserDetailsResponse(
+            email=invited_user_details["email"],
+            account_name=invited_user_details["account_name"],
+        )
+
     @staticmethod
     def create_repository_response(repo: dict) -> RepositoryResponse:
         """
@@ -1012,3 +1024,11 @@ class Converters:
         return AwsCloudProviderSettingsModel(
             sidecar_image_param_name=data.get("sidecar_image_param_name", None)
         )
+
+    @staticmethod
+    def insided_token_model(data: dict):
+        return InsidedTokenResponseModel(
+            access_token=data.get("access_token", None),
+            token_type=data.get("token_type", None),
+            expires_in=data.get("expires_in", None)
+        )
