@@ -877,6 +877,16 @@ class UserInvitationResponse:
         self.space_role = space_role
 
 
+class InvitedUserDetailsResponse:
+    def __init__(
+            self,
+            email: str,
+            account_name: str,
+    ):
+        self.email = email
+        self.account_name = account_name
+
+
 class RepositoryResponse:
     def __init__(self, repository_url: str, errors: List[Error]):
         self.errors = errors
